juju.placement
==============

.. rubric:: Summary

.. automembersummary:: juju.placement

.. rubric:: Reference

.. automodule:: juju.placement
    :members:
    :undoc-members:
    :show-inheritance:
